class Functions:
    SUBSTRING = 'substring'
    EXPLODE = 'explode'
    REPLACE = 'join'
    JOIN = 'join'

class Types:
    PERCENTAGE = 'PERCENTAGE'
    BOOL = 'BOOL'
    MONEY = 'MONEY'
    NUMBER = 'NUMBER'
    INTEGER = 'INTEGER'
    GEO = 'GEO'
    CHAR = 'CHAR'
    URL = 'URL'
    LIST = 'LIST'
    DATE = 'DATE'
    JSON = 'JSON'
    STRING = 'STRING'

class Props:
    TEXT = 'text()'
    HTML = 'html()'